@@ -366,6 +366,10 @@ const DocCommon = new Lang.Class({
         }
     },
 
+    load: function() {
+        log('Error: DocCommon implementations must override load');
+    },
+
     canEdit: function() {
         log('Error: DocCommon implementations must override canEdit');
     },
@@ -379,6 +383,9 @@ const DocCommon = new Lang.Class({
     },
 
     canPrint: function(docModel) {
+        if (this.collection)
+            return false;
+
         if (!docModel)
             return false;
 
@@ -738,6 +745,9 @@ const LocalDocument = new Lang.Class({
             let apps = Gio.app_info_get_recommended_for_type (this.mimeType);
             for (let i = 0; i < apps.length; i++) {
                 if (apps[i].supports_uris ()) {
+                    // Never offer to open in an archive handler
+                    if (apps[i].get_id() == 'org.gnome.FileRoller.desktop')
+                        continue;
                     if (defaultApp && apps[i].equal (defaultApp)) {
                         // Found the recommended app that's also the default
                         recommendedApp = apps[i];
@@ -1514,10 +1524,11 @@ const DocumentManager = new Lang.Class({
 
         this.metadata = new GdPrivate.Metadata({ file: file });
 
-        // save current page in metadata
         let [res, val] = this.metadata.get_int('page');
         if (res)
             docModel.set_page(val);
+
+        // save current page in metadata
         this._activeDocModelIds.push(
             docModel.connect('page-changed', Lang.bind(this,
                 function(source, oldPage, newPage) {
