@@ -50,8 +50,7 @@ const MainWindow = new Lang.Class({
                       width_request: _WINDOW_MIN_WIDTH,
                       height_request: _WINDOW_MIN_HEIGHT,
                       window_position: Gtk.WindowPosition.CENTER,
-                      show_menubar: false,
-                      title: _("Documents") });
+                      show_menubar: false });
 
         // apply the last saved window size and position
         let size = Application.settings.get_value('window-size');
@@ -272,8 +271,7 @@ const MainWindow = new Lang.Class({
             return true;
         }
 
-        if (keyval == Gdk.KEY_space ||
-            keyval == Gdk.KEY_Page_Down) {
+        if (keyval == Gdk.KEY_Page_Down) {
             preview.view.scroll(Gtk.ScrollType.PAGE_FORWARD, false);
             return true;
         }
